@@ -17,7 +17,7 @@ Params::Callbacks - Make your subroutines accept blocking callbacks
 
 =head1 SYNOPSIS
 
-    use Params::Callbacks ':all';
+    use Params::Callbacks 'callbacks', 'callback';  # Or use ':all' tag
     use Data::Dumper;
     
     $Data::Dumper::Indent = 0;
@@ -64,7 +64,7 @@ use Scalar::Util qw(blessed);
 use Carp qw(confess);
 use namespace::clean;
 
-our $VERSION = '2.001000';
+our $VERSION = '2.001001';
 $VERSION = eval $VERSION;
 
 our @ISA         = qw(Exporter);
@@ -260,6 +260,10 @@ sub callback (&;@)
 
 1;
 
+=head1 REPOSITORY
+
+L<https://github.com/cpanic/Params-Callbacks>
+
 =head1 BUG REPORTS
 
 Please report any bugs to L<http://rt.cpan.org/>
